.. _CLI-usage:

CLI Usage
=========

.. include:: ../README.rst
   :start-after: .. _README-Quick-Start:
   :end-before: .. _README-Quick-Start-End:

.. _API-usage:

API Usage
=========

.. include:: ../README.rst
   :start-after: .. _README-Slow-Start:
   :end-before: .. _README-Notifications:
